.. -*- mode: rst ; ispell-local-dictionary: "american" -*-


git flow |BRANCH| start - Start a new |BRANCH| branch
========================================================


Synopsis
-----------

.. parsed-literal::

  `git flow` |`BRANCH`| `start` [-F|--fetch] name [base]


Description
-----------

Start new |BRANCH| ``name``, optionally basing it on ``base`` instead
of |BASE|.


Options
-----------

  -h, --help   Show help message and exit.
  -F, --fetch  Fetch from origin before performing local operation.
